@@ -6,9 +6,11 @@ import rest_framework
 from rest_framework import fields, relations
 
 from .action import Actions
-from .mixins import (ActionMixin, AllowTagsMixin, BooleanFieldMixin, DateFieldMixin, DateTimeFieldMixin, DisplayMode,
-                     FieldHelpTextMixin, HiddenFieldMixin, NullChoiceMixin, NullIntegerMixin, PasswordFieldMixin,
-                     RelatedFieldAJAXMixin, RenderMixin, RTFFieldMixin, TimeFieldMixin)
+from .mixins import (
+    ActionMixin, RenderMixin, DisplayMode, AllowTagsMixin, NullChoiceMixin, RelatedFieldAJAXMixin, FieldHelpTextMixin,
+    PasswordFieldMixin, NullIntegerMixin, EnableCopyMixin, BooleanFieldMixin, DateTimeFieldMixin, DateFieldMixin,
+    TimeFieldMixin, HiddenFieldMixin, RTFFieldMixin
+)
 from .settings import version_check
 
 
@@ -213,8 +215,8 @@ class DurationField(RenderMixin, ActionMixin, FieldHelpTextMixin, fields.Duratio
         super().__init__(**kwargs)
 
 
-class ChoiceField(AllowTagsMixin, NullChoiceMixin, RenderMixin, ActionMixin, FieldHelpTextMixin, fields.ChoiceField):
-
+class ChoiceField(AllowTagsMixin, NullChoiceMixin, EnableCopyMixin, RenderMixin, ActionMixin, FieldHelpTextMixin,
+                  fields.ChoiceField):
     def __init__(self, choices, read_only=False, write_only=False, required=None, default=fields.empty,
                  initial=fields.empty, source=None, label=None, help_text=None, style=None, error_messages=None,
                  validators=None, allow_null=False, allow_tags=False, actions: Actions = None, uuid: UUID = None,
@@ -225,8 +227,8 @@ class ChoiceField(AllowTagsMixin, NullChoiceMixin, RenderMixin, ActionMixin, Fie
         super().__init__(**kwargs)
 
 
-class MultipleChoiceField(AllowTagsMixin, NullChoiceMixin, RenderMixin, ActionMixin, FieldHelpTextMixin,
-                          fields.MultipleChoiceField):
+class MultipleChoiceField(AllowTagsMixin, NullChoiceMixin, EnableCopyMixin, RenderMixin, ActionMixin,
+                          FieldHelpTextMixin, fields.MultipleChoiceField):
     def __init__(self, choices, read_only=False, write_only=False, required=None, default=fields.empty,
                  initial=fields.empty, source=None, label=None, help_text=None, style=None, error_messages=None,
                  validators=None, allow_null=False, allow_tags=False, actions: Actions = None, uuid: UUID = None,
@@ -237,7 +239,7 @@ class MultipleChoiceField(AllowTagsMixin, NullChoiceMixin, RenderMixin, ActionMi
         super().__init__(**kwargs)
 
 
-class FilePathField(AllowTagsMixin, NullChoiceMixin, RenderMixin, ActionMixin, FieldHelpTextMixin,
+class FilePathField(AllowTagsMixin, NullChoiceMixin, EnableCopyMixin, RenderMixin, ActionMixin, FieldHelpTextMixin,
                     fields.FilePathField):
     def __init__(self, path, match=None, recursive=False, allow_files=True, allow_folders=False, required=None,
                  read_only=False, write_only=False, default=fields.empty, initial=fields.empty, source=None,
